@@ -1,10 +1,10 @@
-#PBS -l select=32:model=mil_a100:ncpus=44:ngpus=2:mem=250GB
+#PBS -l select=2:model=mil_a100:ncpus=40:ngpus=4:mem=250GB
 #PBS -l place=scatter:excl
-#PBS -l walltime=120:00:00
+#PBS -l walltime=02:00:00
 #PBS -j oe
 #PBS -W group_list=s2853
-#PBS -q gpu_long@pbspl4
-session_name="32_node_2_gpus_1_pp_500m_qi_loss_continued"
+#PBS -q gpu_debug@pbspl4
+session_name="session_name"
 current_time=$(date "+%Y_%m_%d_%H_%M_%S")
 export HAPLO_SESSION_DIRECTORY="sessions/${current_time}_${session_name}"
 mkdir -p "${HAPLO_SESSION_DIRECTORY}"
@@ -23,11 +23,11 @@ head_node_hostname=`/bin/hostname -s`
 export MPI_SHEPHERD=true
 export MPI_DSM_DISTRIBUTE=0
 export OMP_NUM_THREADS=11
-export CUDA_VISIBLE_DEVICES=0,1
+export CUDA_VISIBLE_DEVICES=0,1,2,3
 
 mpiexec -perhost 1 python -m torch.distributed.run \
---nnodes 32 \
---nproc_per_node 2 \
+--nnodes 2 \
+--nproc_per_node 4 \
 --rdzv_id $RANDOM \
 --rdzv_backend c10d \
 --rdzv_endpoint $head_node_hostname \
