@@ -1,14 +1,14 @@
 #!/bin/bash
 
 #SBATCH --job-name="¯\\_(ツ)_/¯"
-#SBATCH --nodes=1
-#SBATCH --ntasks=1
-#SBATCH --gpus-per-task=1
+#SBATCH --nodes=4
+#SBATCH --ntasks=4
+#SBATCH --gpus-per-task=4
 #SBATCH --cpus-per-task=40
 #SBATCH --mem=600000
-#SBATCH --time=1-00:00:00
+#SBATCH --time=5-00:00:00
 
-session_name="base_old_version"
+session_name="session_name"
 current_time=$(date "+%Y_%m_%d_%H_%M_%S")
 export HAPLO_SESSION_DIRECTORY="sessions/${current_time}_${session_name}"
 mkdir -p "${HAPLO_SESSION_DIRECTORY}"
@@ -23,8 +23,8 @@ echo Node IP: $head_node_ip
 export OMP_NUM_THREADS=11
 
 srun torchrun \
---nnodes 1 \
---nproc_per_node 1 \
+--nnodes 4 \
+--nproc_per_node gpu \
 --rdzv_id $RANDOM \
 --rdzv_backend c10d \
 --rdzv_endpoint $head_node_ip:36484 \
